==> nertc_core_platform_interface-4.6.52-rc.1.tar.gz: lib/platform_interface/nertc_engine_platform_interface.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:nertc_core_platform_interface/pigeon.dart';
import 'package:nertc_core_platform_interface/nertc_core_platform_interface.dart';

abstract class NERtcEnginePlatform extends PlatformInterface {
  NERtcEnginePlatform() : super(token: _token);

  static final Object _token = Object();

  static NERtcEnginePlatform _instance = MethodChannelNERtcEngine();

  static NERtcEnginePlatform get instance => _instance;

  static set instance(NERtcEnginePlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  void addRtcChannelListener(NERtcChannelEventSink sink);

  void removeRtcChannelListener(NERtcChannelEventSink sink);

  Future<int> create(String appKey, NERtcOptions? options);

  Future<int> release();

  Future<NERtcVersion> version();

  Future<List<String?>?> checkPermission();

  Future<int> setParameters(Map<String, Object> params);

  Future<int> setStatsEventCallback();

  Future<int> clearStatsEventCallback();

  Future<int> joinChannel(String? token, String channelName, int uid,
      [NERtcJoinChannelOptions? channelOptions]);

  Future<int> leaveChannel();

  Future<int> updatePermissionKey(String key);

  Future<int> enableLocalAudio(bool enable);

  Future<int> subscribeRemoteAudio(int uid, bool subscribe);

  Future<int> subscribeAllRemoteAudio(bool subscribe);

  Future<int> setAudioProfile(
      NERtcAudioProfile profile, NERtcAudioScenario scenario);

  Future<int> enableLocalVideo(bool enable, int streamType);

  Future<int> setLocalVideoConfig(NERtcVideoConfig videoConfig, int streamType);

  Future<int> setCameraCaptureConfig(
      NERtcCameraCaptureConfig captureConfig, int streamType);

  Future<int> startVideoPreview(int streamType);

  Future<int> stopVideoPreview(int streamType);

  Future<int> startScreenCapture(NERtcScreenConfig config);

  Future<int> stopScreenCapture();

  Future<int> enableLoopbackRecording(bool enable);

  Future<int> subscribeRemoteVideoStream(
      int uid, int streamType, bool subscribe);

  Future<int> subscribeRemoteSubStreamVideo(int uid, bool subscribe);

  Future<int> subscribeRemoteSubStreamAudio(int uid, bool subscribe);

  Future<int> muteLocalAudioStream(bool mute);

  Future<int> muteLocalVideoStream(bool mute, int streamType);

  Future<int> muteLocalSubStreamAudio(bool muted);

  Future<int> enableLocalSubStreamAudio(bool enable);

  Future<int> setAudioSubscribeOnlyBy(List<int>? uidArray);

  Future<int> startAudioDump();

  Future<int> startAudioDumpWithType(int dumpType);

  Future<int> stopAudioDump();

  Future<int> enableAudioVolumeIndication(bool enable, int interval, bool vad);

  Future<int> setChannelProfile(int channelProfile);

  Future<int> enableDualStreamMode(bool enable);

  Future<int> addLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo);

  Future<int> updateLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo);

  Future<int> removeLiveStreamTask(String taskId);

  Future<int> adjustRecordingSignalVolume(int volume);

  Future<int> adjustPlaybackSignalVolume(int volume);

  Future<int> adjustLoopBackRecordingSignalVolume(int volume);

  Future<int> setClientRole(int role);

  Future<int> getConnectionState();

  Future<int> uploadSdkInfo();

  Future<int> sendSEIMsg(String seiMsg, int streamType);

  Future<int> setAudioEffectPreset(int preset);

  Future<int> setVoiceBeautifierPreset(int preset);

  Future<int> setLocalVoiceEqualization(int bandFrequency, int bandGain);

  Future<int> setLocalVoicePitch(double pitch);

  Future<int> setLocalVoiceReverbParam(NERtcReverbParam param);

  Future<int> switchChannel(String? token, String channelName,
      {NERtcJoinChannelOptions? channelOptions});

  Future<int> startAudioRecording(String filePath, int sampleRate, int quality);

  Future<int> startAudioRecordingWithConfig(
      NERtcAudioRecordingConfiguration config);

  Future<int> stopAudioRecording();

  Future<int> setLocalMediaPriority(int priority, bool isPreemptive);

  Future<int> enableMediaPub(int mediaType, bool enable);

  Future<int> startChannelMediaRelay(
      NERtcChannelMediaRelayConfiguration config);

  Future<int> updateChannelMediaRelay(
      NERtcChannelMediaRelayConfiguration config);

  Future<int> stopChannelMediaRelay();

  Future<int> reportCustomEvent(
      String eventName, String? customIdentify, Map<String?, Object?>? param);

  Future<int> adjustUserPlaybackSignalVolume(int uid, int volume);

  Future<int> enableSuperResolution(bool enable);

  Future<int> enableEncryption(bool enable, NERtcEncryptionConfig config);

  Future<int> setAudioSessionOperationRestriction(
      NERtcAudioSessionOperationRestriction restriction);

  Future<int> setRemoteSubscribeFallbackOption(int option);

  Future<int> setLocalPublishFallbackOption(int option);

  Future<int> getEffectDuration(int effectId);

  // Future<int> getEffectCurrentPosition(int effectId);

  Future<int> startLastmileProbeTest(LastmileProbeConfig config);

  Future<int> stopLastmileProbeTest();

  Future<int> setVideoCorrectionConfig(
      NERtcVideoCorrectionConfiguration? config);

  Future<int> enableVirtualBackground(
      bool enabled, NERtcVirtualBackgroundSource backgroundSource);

  Future<int> setRemoteHighPriorityAudioStream(
      bool enabled, int uid, int streamType);

  Future<int> setCloudProxy(int proxyType);

  Future<int> startBeauty();

  Future<void> stopBeauty();

  Future<int> enableBeauty(bool enabled);

  Future<int> setBeautyEffect(double level, int beautyType);

  Future<int> addBeautyFilter(String path, String name);

  Future<void> removeBeautyFilter();

  Future<int> setBeautyFilterLevel(double level);

  Future<int> setLocalVideoWatermarkConfigs(
      int type, NERtcVideoWatermarkConfig config);

  Future<int> setStreamAlignmentProperty(bool enable);

  Future<int> getNtpTimeOffset();

  Future<int> takeLocalSnapshot(int streamType, String path);

  Future<int> takeRemoteSnapshot(int uid, int streamType, String path);

  Future<int> enableVideoCorrection(bool enable);
}

==> nertc_core_platform_interface-5.4.0.tar.gz: lib/platform_interface/nertc_engine_platform_interface.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:nertc_core_platform_interface/pigeon.dart';
import 'package:nertc_core_platform_interface/nertc_core_platform_interface.dart';

abstract class NERtcEnginePlatform extends PlatformInterface {
  NERtcEnginePlatform() : super(token: _token);

  static final Object _token = Object();

  static NERtcEnginePlatform _instance = MethodChannelNERtcEngine();

  static NERtcEnginePlatform get instance => _instance;

  static set instance(NERtcEnginePlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  void addRtcChannelListener(NERtcChannelEventSink sink);

  void removeRtcChannelListener(NERtcChannelEventSink sink);

  Future<int> create(String appKey, NERtcOptions? options);

  Future<int> release();

  Future<NERtcVersion> version();

  Future<List<String?>?> checkPermission();

  Future<int> setParameters(Map<String, Object> params);

  Future<int> setStatsEventCallback();

  Future<int> clearStatsEventCallback();

  Future<int> joinChannel(String? token, String channelName, int uid,
      [NERtcJoinChannelOptions? channelOptions]);

  Future<int> leaveChannel();

  Future<int> updatePermissionKey(String key);

  Future<int> enableLocalAudio(bool enable);

  Future<int> subscribeRemoteAudio(int uid, bool subscribe);

  Future<int> subscribeAllRemoteAudio(bool subscribe);

  Future<int> setAudioProfile(
      NERtcAudioProfile profile, NERtcAudioScenario scenario);

  Future<int> enableLocalVideo(bool enable, int streamType);

  Future<int> setLocalVideoConfig(NERtcVideoConfig videoConfig, int streamType);

  Future<int> setCameraCaptureConfig(
      NERtcCameraCaptureConfig captureConfig, int streamType);

  Future<int> startVideoPreview(int streamType);

  Future<int> stopVideoPreview(int streamType);

  Future<int> startScreenCapture(NERtcScreenConfig config);

  Future<int> stopScreenCapture();

  Future<int> enableLoopbackRecording(bool enable);

  Future<int> subscribeRemoteVideoStream(
      int uid, int streamType, bool subscribe);

  Future<int> subscribeRemoteSubStreamVideo(int uid, bool subscribe);

  Future<int> subscribeRemoteSubStreamAudio(int uid, bool subscribe);

  Future<int> muteLocalAudioStream(bool mute);

  Future<int> muteLocalVideoStream(bool mute, int streamType);

  Future<int> muteLocalSubStreamAudio(bool muted);

  Future<int> enableLocalSubStreamAudio(bool enable);

  Future<int> setAudioSubscribeOnlyBy(List<int>? uidArray);

  Future<int> startAudioDump();

  Future<int> startAudioDumpWithType(int dumpType);

  Future<int> stopAudioDump();

  Future<int> enableAudioVolumeIndication(bool enable, int interval, bool vad);

  Future<int> setChannelProfile(int channelProfile);

  Future<int> enableDualStreamMode(bool enable);

  Future<int> addLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo);

  Future<int> updateLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo);

  Future<int> removeLiveStreamTask(String taskId);

  Future<int> adjustRecordingSignalVolume(int volume);

  Future<int> adjustPlaybackSignalVolume(int volume);

  Future<int> adjustLoopBackRecordingSignalVolume(int volume);

  Future<int> setClientRole(int role);

  Future<int> getConnectionState();

  Future<int> uploadSdkInfo();

  Future<int> sendSEIMsg(String seiMsg, int streamType);

  Future<int> setAudioEffectPreset(int preset);

  Future<int> setVoiceBeautifierPreset(int preset);

  Future<int> setLocalVoiceEqualization(int bandFrequency, int bandGain);

  Future<int> setLocalVoicePitch(double pitch);

  Future<int> setLocalVoiceReverbParam(NERtcReverbParam param);

  Future<int> switchChannel(String? token, String channelName,
      {NERtcJoinChannelOptions? channelOptions});

  Future<int> startAudioRecording(String filePath, int sampleRate, int quality);

  Future<int> startAudioRecordingWithConfig(
      NERtcAudioRecordingConfiguration config);

  Future<int> stopAudioRecording();

  Future<int> setLocalMediaPriority(int priority, bool isPreemptive);

  Future<int> enableMediaPub(int mediaType, bool enable);

  Future<int> startChannelMediaRelay(
      NERtcChannelMediaRelayConfiguration config);

  Future<int> updateChannelMediaRelay(
      NERtcChannelMediaRelayConfiguration config);

  Future<int> stopChannelMediaRelay();

  Future<int> reportCustomEvent(
      String eventName, String? customIdentify, Map<String?, Object?>? param);

  Future<int> adjustUserPlaybackSignalVolume(int uid, int volume);

  Future<int> enableSuperResolution(bool enable);

  Future<int> enableEncryption(bool enable, NERtcEncryptionConfig config);

  Future<int> setAudioSessionOperationRestriction(
      NERtcAudioSessionOperationRestriction restriction);

  Future<int> setRemoteSubscribeFallbackOption(int option);

  Future<int> setLocalPublishFallbackOption(int option);

  Future<int> getEffectDuration(int effectId);

  // Future<int> getEffectCurrentPosition(int effectId);

  Future<int> startLastmileProbeTest(LastmileProbeConfig config);

  Future<int> stopLastmileProbeTest();

  Future<int> setVideoCorrectionConfig(
      NERtcVideoCorrectionConfiguration? config);

  Future<int> enableVirtualBackground(
      bool enabled, NERtcVirtualBackgroundSource? backgroundSource);

  Future<int> setRemoteHighPriorityAudioStream(
      bool enabled, int uid, int streamType);

  Future<int> setCloudProxy(int proxyType);

  Future<int> startBeauty();

  Future<void> stopBeauty();

  Future<int> enableBeauty(bool enabled);

  Future<int> setBeautyEffect(double level, int beautyType);

  Future<int> addBeautyFilter(String path, String name);

  Future<void> removeBeautyFilter();

  Future<int> setBeautyFilterLevel(double level);

  Future<int> setLocalVideoWatermarkConfigs(
      int type, NERtcVideoWatermarkConfig? config);

  Future<int> setStreamAlignmentProperty(bool enable);

  Future<int> getNtpTimeOffset();

  Future<int> takeLocalSnapshot(int streamType, String path);

  Future<int> takeRemoteSnapshot(int uid, int streamType, String path);

  Future<int> enableVideoCorrection(bool enable);
}
